django-skivvy
-------------

django-skivvy helps you write better and more readable tests for Django views.

.. image:: https://travis-ci.org/Cadasta/django-skivvy.svg?branch=master
    :target: https://travis-ci.org/Cadasta/django-skivvy

Requirements
~~~~~~~~~~~~
- Python 3.4, 3.5
- Django 1.9, 1.10


Installation
~~~~~~~~~~~~

.. code-block::

    pip install django-skivvy

Usage
~~~~~
Refer to the `documentation <https://cadasta.github.io/django-skivvy/#django-skivvy>`_ for further details.


Documentation
~~~~~~~~~~~~~

Docs live inside ``docs``, as a `DocBox <https://github.com/mapbox/docbox>`_ app. To change the content of the docs, edit the Markdown files in ``docs/content``.

There's a script to help you build and deploy docs to the `gh-pages` branch. To deploy, run:

.. code-block::

    ./.deploy/deploy.sh
